@@ -179,14 +179,18 @@ test_for_alias_sync (Test *test,
 	SecretCollection *collection;
 	GError *error = NULL;
 
-	collection = secret_collection_for_alias_sync (test->service, "default", NULL, &error);
+	collection = secret_collection_for_alias_sync (test->service, "default",
+	                                               SECRET_COLLECTION_NONE, NULL, &error);
 	g_assert_no_error (error);
 
 	collection_path = g_dbus_proxy_get_object_path (G_DBUS_PROXY (collection));
 	g_assert_cmpstr (collection_path, ==, "/org/freedesktop/secrets/collection/english");
+	g_assert_cmpuint (secret_collection_get_flags (collection), ==, SECRET_COLLECTION_NONE);
+	g_assert (secret_collection_get_items (collection) == NULL);
 	g_object_unref (collection);
 
-	collection = secret_collection_for_alias_sync (test->service, "unknown", NULL, &error);
+	collection = secret_collection_for_alias_sync (test->service, "unknown",
+	                                               SECRET_COLLECTION_NONE, NULL, &error);
 	g_assert_no_error (error);
 	g_assert (collection == NULL);
 }
@@ -200,8 +204,9 @@ test_for_alias_async (Test *test,
 	GAsyncResult *result = NULL;
 	GError *error = NULL;
 
-	secret_collection_for_alias (test->service, "default", NULL,
-	                             on_async_result, &result);
+	secret_collection_for_alias (test->service, "default",
+	                             SECRET_COLLECTION_NONE,
+	                             NULL, on_async_result, &result);
 	g_assert (result == NULL);
 	egg_test_wait ();
 
@@ -211,11 +216,14 @@ test_for_alias_async (Test *test,
 
 	collection_path = g_dbus_proxy_get_object_path (G_DBUS_PROXY (collection));
 	g_assert_cmpstr (collection_path, ==, "/org/freedesktop/secrets/collection/english");
+	g_assert_cmpuint (secret_collection_get_flags (collection), ==, SECRET_COLLECTION_NONE);
+	g_assert (secret_collection_get_items (collection) == NULL);
 	g_object_unref (collection);
 	result = NULL;
 
-	secret_collection_for_alias (test->service, "unknown", NULL,
-	                             on_async_result, &result);
+	secret_collection_for_alias (test->service, "unknown",
+	                             SECRET_COLLECTION_NONE,
+	                             NULL, on_async_result, &result);
 	g_assert (result == NULL);
 	egg_test_wait ();
 
@@ -225,6 +233,58 @@ test_for_alias_async (Test *test,
 	g_object_unref (result);
 }
 
+static void
+test_for_alias_load_sync (Test *test,
+                          gconstpointer used)
+{
+	const gchar *collection_path;
+	SecretCollection *collection;
+	GError *error = NULL;
+	GList *items;
+
+	collection = secret_collection_for_alias_sync (test->service, "default",
+	                                               SECRET_COLLECTION_LOAD_ITEMS,
+	                                               NULL, &error);
+	g_assert_no_error (error);
+
+	collection_path = g_dbus_proxy_get_object_path (G_DBUS_PROXY (collection));
+	g_assert_cmpstr (collection_path, ==, "/org/freedesktop/secrets/collection/english");
+	g_assert_cmpuint (secret_collection_get_flags (collection), ==, SECRET_COLLECTION_LOAD_ITEMS);
+	items = secret_collection_get_items (collection);
+	g_assert (items != NULL);
+	g_list_free_full (items, g_object_unref);
+	g_object_unref (collection);
+}
+
+static void
+test_for_alias_load_async (Test *test,
+                           gconstpointer used)
+{
+	const gchar *collection_path;
+	SecretCollection *collection;
+	GAsyncResult *result = NULL;
+	GError *error = NULL;
+	GList *items;
+
+	secret_collection_for_alias (test->service, "default",
+	                             SECRET_COLLECTION_LOAD_ITEMS,
+	                             NULL, on_async_result, &result);
+	g_assert (result == NULL);
+	egg_test_wait ();
+
+	collection = secret_collection_for_alias_finish (result, &error);
+	g_assert_no_error (error);
+	g_object_unref (result);
+
+	collection_path = g_dbus_proxy_get_object_path (G_DBUS_PROXY (collection));
+	g_assert_cmpstr (collection_path, ==, "/org/freedesktop/secrets/collection/english");
+	g_assert_cmpuint (secret_collection_get_flags (collection), ==, SECRET_COLLECTION_LOAD_ITEMS);
+	items = secret_collection_get_items (collection);
+	g_assert (items != NULL);
+	g_list_free_full (items, g_object_unref);
+	g_object_unref (collection);
+	result = NULL;
+}
 
 static void
 test_create_sync (Test *test,
@@ -935,6 +995,8 @@ main (int argc, char **argv)
 	g_test_add ("/collection/new-async-noexist", Test, "mock-service-normal.py", setup, test_new_async_noexist, teardown);
 	g_test_add ("/collection/for-alias-sync", Test, "mock-service-normal.py", setup, test_for_alias_sync, teardown);
 	g_test_add ("/collection/for-alias-async", Test, "mock-service-normal.py", setup, test_for_alias_async, teardown);
+	g_test_add ("/collection/for-alias-load-sync", Test, "mock-service-normal.py", setup, test_for_alias_load_sync, teardown);
+	g_test_add ("/collection/for-alias-load-async", Test, "mock-service-normal.py", setup, test_for_alias_load_async, teardown);
 	g_test_add ("/collection/create-sync", Test, "mock-service-normal.py", setup, test_create_sync, teardown);
 	g_test_add ("/collection/create-async", Test, "mock-service-normal.py", setup, test_create_async, teardown);
 	g_test_add ("/collection/properties", Test, "mock-service-normal.py", setup, test_properties, teardown);
